Package: wppi
Type: Package
Title: Weighting protein-protein interactions
Version: 1.19.0
Authors@R: c(
    person(
        given = "Ana",
        family = "Galhoz",
        role = c("cre", "aut"),
        email = "ana.galhoz@helmholtz-muenchen.de",
        comment = c(ORCID = "0000-0001-7402-5292")),
    person(
        given = "Denes",
        family = "Turei",
        role = "aut",
        email = "turei.denes@gmail.com",
        comment = c(ORCID = "0000-0002-7249-9379")),
    person(
        given = "Michael",
        family = "P. Menden",
        role = "aut",
        email = "michael.menden@helmholtz-muenchen.de",
        comment = c(ORCID = "0000-0003-0267-5792")),
    #
    # Copyright holders
    person("Albert", "Krewinkel", role = c("ctb", "cph"), 
         comment = "pagebreak Lua filter")
    )
Description: Protein-protein interaction data is essential for omics data
    analysis and modeling. Database knowledge is general, not specific for
    cell type, physiological condition or any other context determining which
    connections are functional and contribute to the signaling. Functional
    annotations such as Gene Ontology and Human Phenotype Ontology might help
    to evaluate the relevance of interactions. This package predicts
    functional relevance of protein-protein interactions based on functional
    annotations such as Human Protein Ontology and Gene Ontology, and
    prioritizes genes based on network topology, functional scores and a path
    search algorithm.
License: MIT + file LICENSE
URL: https://github.com/AnaGalhoz37/wppi
BugReports: https://github.com/AnaGalhoz37/wppi/issues
biocViews: GraphAndNetwork, Network, Pathways, Software, GeneSignaling,
        GeneTarget, SystemsBiology, Transcriptomics, Annotation
Encoding: UTF-8
VignetteBuilder: knitr
Depends: R(>= 4.1)
Imports: dplyr, igraph, logger, methods, magrittr, Matrix, OmnipathR(>=
        2.99.8), progress, purrr, rlang, RCurl, stats, tibble, tidyr
Suggests: knitr, testthat, rmarkdown
RoxygenNote: 7.1.1
NeedsCompilation: no
git_url: https://git.bioconductor.org/packages/wppi
git_branch: devel
git_last_commit: 40fc535
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-18
Packaged: 2025-11-19 02:38:50 UTC; biocbuild
Author: Ana Galhoz [cre, aut] (ORCID: <https://orcid.org/0000-0001-7402-5292>),
  Denes Turei [aut] (ORCID: <https://orcid.org/0000-0002-7249-9379>),
  Michael P. Menden [aut] (ORCID:
    <https://orcid.org/0000-0003-0267-5792>),
  Albert Krewinkel [ctb, cph] (pagebreak Lua filter)
Maintainer: Ana Galhoz <ana.galhoz@helmholtz-muenchen.de>
